1.0.0 API documentation: GLM_EXT_matrix_int4x2_sized

| 1.0.0 API documentation

Typedefs
GLM_EXT_matrix_int4x2_sized
Stable extensions

## Typedefs
typedef mat< 4, 2, int16, defaultp > | i16mat4x2
| 16 bit signed integer 4x2 matrix. More...
typedef mat< 4, 2, int32, defaultp > | i32mat4x2
| 32 bit signed integer 4x2 matrix. More...
typedef mat< 4, 2, int64, defaultp > | i64mat4x2
| 64 bit signed integer 4x2 matrix. More...
typedef mat< 4, 2, int8, defaultp > | i8mat4x2
| 8 bit signed integer 4x2 matrix. More...

## Detailed Description

Include <glm/ext/matrix_int4x2_sized.hpp> to use the features of this extension.

Defines a number of matrices with integer types.

## Typedef Documentation

## ◆ i16mat4x2

typedef mat< 4, 2, int16, defaultp > i16mat4x2

16 bit signed integer 4x2 matrix.

See also
  GLM_EXT_matrix_int4x2_sized

Definition at line 36 of file matrix_int4x2_sized.hpp.

## ◆ i32mat4x2

typedef mat< 4, 2, int32, defaultp > i32mat4x2

32 bit signed integer 4x2 matrix.

See also
  GLM_EXT_matrix_int4x2_sized

Definition at line 41 of file matrix_int4x2_sized.hpp.

## ◆ i64mat4x2

typedef mat< 4, 2, int64, defaultp > i64mat4x2

64 bit signed integer 4x2 matrix.

See also
  GLM_EXT_matrix_int4x2_sized

Definition at line 46 of file matrix_int4x2_sized.hpp.

## ◆ i8mat4x2

typedef mat< 4, 2, int8, defaultp > i8mat4x2

8 bit signed integer 4x2 matrix.

See also
  GLM_EXT_matrix_int4x2_sized

Definition at line 31 of file matrix_int4x2_sized.hpp.